==> rest-assured-1.5-sources.jar: com/jayway/restassured/internal/path/xml/NodeImpl.java <==
package com.jayway.restassured.internal.path.xml;

import java.lang.*;
import java.io.*;
import java.net.*;
import java.util.*;
import groovy.lang.*;
import groovy.util.*;

public class NodeImpl
  extends com.jayway.restassured.internal.path.xml.NodeBase  implements
    com.jayway.restassured.path.xml.element.Node,    groovy.lang.GroovyObject {
public NodeImpl
() {}
public  groovy.lang.MetaClass getMetaClass() { return (groovy.lang.MetaClass)null;}
public  void setMetaClass(groovy.lang.MetaClass mc) { }
public  java.lang.Object invokeMethod(java.lang.String method, java.lang.Object arguments) { return null;}
public  java.lang.Object getProperty(java.lang.String property) { return null;}
public  void setProperty(java.lang.String property, java.lang.Object value) { }
public  java.lang.Object getAttributes() { return null;}
public  void setAttributes(java.lang.Object value) { }
public  com.jayway.restassured.path.xml.element.NodeChildren getChildren() { return (com.jayway.restassured.path.xml.element.NodeChildren)null;}
public  void setChildren(com.jayway.restassured.path.xml.element.NodeChildren value) { }
public  java.lang.Object getName() { return null;}
public  void setName(java.lang.Object value) { }
public  java.lang.Object getValue() { return null;}
public  void setValue(java.lang.Object value) { }
@java.lang.Override() public  java.util.Map<java.lang.String, java.lang.String> attributes() { return (java.util.Map<java.lang.String, java.lang.String>)null;}
@java.lang.Override() public  java.lang.String name() { return (java.lang.String)null;}
@java.lang.Override() public  java.util.Iterator<java.lang.String> iterator() { return (java.util.Iterator<java.lang.String>)null;}
public  java.lang.String toString() { return (java.lang.String)null;}
public  com.jayway.restassured.path.xml.element.NodeChildren children() { return (com.jayway.restassured.path.xml.element.NodeChildren)null;}
public  java.lang.String getAttribute(java.lang.String name) { return (java.lang.String)null;}
public  float getFloat(java.lang.String name) { return (float)0;}
public  double getDouble(java.lang.String name) { return (double)0;}
public  char getChar(java.lang.String name) { return (char)0;}
public  boolean getBoolean(java.lang.String name) { return false;}
public  long getLong(java.lang.String name) { return (long)0;}
public  int getInt(java.lang.String name) { return (int)0;}
public  short getShort(java.lang.String name) { return (short)0;}
public  byte getByte(java.lang.String name) { return (byte)0;}
public <T> T get(java.lang.String name) { return null;}
@java.lang.Override() public  java.lang.String value() { return (java.lang.String)null;}
@java.lang.Override() public <T> java.util.List<T> getList(java.lang.String name) { return (java.util.List<T>)null;}
public class ValueIterator
  extends java.lang.Object  implements
    java.util.Iterator<java.lang.String>,    groovy.lang.GroovyObject {
public ValueIterator
() {}
public  groovy.lang.MetaClass getMetaClass() { return (groovy.lang.MetaClass)null;}
public  void setMetaClass(groovy.lang.MetaClass mc) { }
public  java.lang.Object invokeMethod(java.lang.String method, java.lang.Object arguments) { return null;}
public  java.lang.Object getProperty(java.lang.String property) { return null;}
public  void setProperty(java.lang.String property, java.lang.Object value) { }
public  java.lang.Object getHasNext() { return null;}
public  void setHasNext(java.lang.Object value) { }
@java.lang.Override() public  boolean hasNext() { return false;}
@java.lang.Override() public  java.lang.String next() { return (java.lang.String)null;}
@java.lang.Override() public  void remove() { }
}
}

==> rest-assured-1.7.2-sources.jar: com/jayway/restassured/internal/path/xml/NodeImpl.java <==
package com.jayway.restassured.internal.path.xml;

import java.lang.*;
import java.io.*;
import java.net.*;
import java.util.*;
import groovy.lang.*;
import groovy.util.*;

public class NodeImpl
  extends com.jayway.restassured.internal.path.xml.NodeBase  implements
    com.jayway.restassured.path.xml.element.Node {
public  groovy.lang.MetaClass getMetaClass() { return (groovy.lang.MetaClass)null;}
public  void setMetaClass(groovy.lang.MetaClass mc) { }
public  java.lang.Object invokeMethod(java.lang.String method, java.lang.Object arguments) { return null;}
public  java.lang.Object getProperty(java.lang.String property) { return null;}
public  void setProperty(java.lang.String property, java.lang.Object value) { }
public  java.lang.Object getAttributes() { return null;}
public  void setAttributes(java.lang.Object value) { }
public  com.jayway.restassured.path.xml.element.NodeChildren getChildren() { return (com.jayway.restassured.path.xml.element.NodeChildren)null;}
public  void setChildren(com.jayway.restassured.path.xml.element.NodeChildren value) { }
public  java.lang.Object getName() { return null;}
public  void setName(java.lang.Object value) { }
public  java.lang.Object getValue() { return null;}
public  void setValue(java.lang.Object value) { }
@java.lang.Override() public  java.util.Map<java.lang.String, java.lang.String> attributes() { return (java.util.Map<java.lang.String, java.lang.String>)null;}
@java.lang.Override() public  java.lang.String name() { return (java.lang.String)null;}
@java.lang.Override() public  java.util.Iterator<java.lang.String> iterator() { return (java.util.Iterator<java.lang.String>)null;}
public  java.lang.String toString() { return (java.lang.String)null;}
public  com.jayway.restassured.path.xml.element.NodeChildren children() { return (com.jayway.restassured.path.xml.element.NodeChildren)null;}
public  java.lang.String getAttribute(java.lang.String name) { return (java.lang.String)null;}
public  float getFloat(java.lang.String name) { return (float)0;}
public  double getDouble(java.lang.String name) { return (double)0;}
public  char getChar(java.lang.String name) { return (char)0;}
public  boolean getBoolean(java.lang.String name) { return false;}
public  long getLong(java.lang.String name) { return (long)0;}
public  int getInt(java.lang.String name) { return (int)0;}
public  short getShort(java.lang.String name) { return (short)0;}
public  byte getByte(java.lang.String name) { return (byte)0;}
public <T> T get(java.lang.String name) { return null;}
@java.lang.Override() public  java.lang.String value() { return (java.lang.String)null;}
@java.lang.Override() public <T> java.util.List<T> getList(java.lang.String name) { return (java.util.List<T>)null;}
public class ValueIterator
  extends java.lang.Object  implements
    java.util.Iterator<java.lang.String>,    groovy.lang.GroovyObject {
public  groovy.lang.MetaClass getMetaClass() { return (groovy.lang.MetaClass)null;}
public  void setMetaClass(groovy.lang.MetaClass mc) { }
public  java.lang.Object invokeMethod(java.lang.String method, java.lang.Object arguments) { return null;}
public  java.lang.Object getProperty(java.lang.String property) { return null;}
public  void setProperty(java.lang.String property, java.lang.Object value) { }
public  java.lang.Object getHasNext() { return null;}
public  void setHasNext(java.lang.Object value) { }
@java.lang.Override() public  boolean hasNext() { return false;}
@java.lang.Override() public  java.lang.String next() { return (java.lang.String)null;}
@java.lang.Override() public  void remove() { }
}
}
